module ParichkiBg
  module Request

    class UsedRequestId < StandardError
    end
    
    class Query < ParichkiBg::Request::Base
      attr_reader :status

      #status 0 unused request_id
      #status 1 used   request_id

      def initialize(attributes = {})
        super
        @pin = attributes[:pin]
        @status = 0
      end

      def uri
        URI "#{ParichkiBg::main_api_url}/#{user_id}/data?vendor_id=#{ParichkiBg::vendor_id}&signed_request=#{signed_request}"
      end

      def send
        @status = 0
        super
      end

      def to_json
        {
          amount: "#{amount}"
        }.to_json
      end

      def can_pay?
        !!result["allow_virtual"]        
      end

      def success?
        !!( @response.code == "200" && @response.body.match(/user_id/) )
      end

      def build_transaction
        raise UsedRequestId if @status == 1
        used_request_id
        Transaction.new(amount: amount, request_id: result["request_id"], user_id: user_id, pin: pin)
      end

      def make_cash_transaction
        build_transaction.tap {|x| x.pay_with_cash}
      end

      def make_point_transaction
        build_transaction.tap {|x| x.pay_with_points}
      end

      private

      def used_request_id
        @status = 1
      end

    end

  end
end